%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%                                                                      %%%%%
%%%%%     Default parameter settings for the LaTeX ``TeXtopo'' package     %%%%%
%%%%%                                                                      %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%                                                                      %%%%%
%%%%%   This example file contains all standard  settings of the TeXtopo   %%%%%
%%%%%   package. It can be used as a template for the creation of perso-   %%%%%
%%%%%   nal parameter files.  All TeXtopo user commands are  allowed and   %%%%%
%%%%%   functional when specified here.                                    %%%%%
%%%%%                                                                      %%%%%
%%%%%   To activate these settings for your topology plot load this file   %%%%%
%%%%%   by naming it as optional parameter  at the beginning of the tex-   %%%%%
%%%%%   topo environment, e.g.                                             %%%%%
%%%%%                                                                      %%%%%
%%%%%          \begin{textopo}[myparameterfile]                            %%%%%
%%%%%             .                                                        %%%%%
%%%%%             .                                                        %%%%%
%%%%%          \end{textopo}                                               %%%%%
%%%%%                                                                      %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\Nterm{intra}                       %  Assume N-terminus intracellular
\loopextent{30}                     %  Set loop extent to 30 residues
\shadingcolors{blues}               %  Use color scheme `blues' for shading
\showmembrane                       %  Show the membrane
\membranecolors{Black}{White}       %        as black lines w/o filling
\labeloutside{extra}                %  Label extracellular side with `extra'
\labelinside{intra}                 %  Label intracellular side with `intra'
\rulethickness{0.5pt}               %  Set thickness of label rules to 0.5pt
\countercolor{Red}                  %  Use red color for position counter
\helixstyle{perspective}            %  Draw helical wheels in perspective
\showbonds                          %  Show bonds on helical wheels
\hidemoment                         %  Do not show hydrophobic moment
\momentcolor{Lavender}              %  Lavender color for hydrophobic moment
\scalemoment{100}                   %  Moment rule length is 100%
\showwheelnumbering                 %  Show residue numbers on helical wheels
\scalewheel{100}                    %  Show full size helical wheel
\symbolsize{medium}                 %  Use medium sized symbols in wheels
\donotshadestartMet                 %  Do not shade the start methionine
\showNterm                          %  Show amino terminus as NH2
\showCterm                          %  Show carboxy terminus as COOH

\setfamily{labels}{sf}              %  Use sans serif family for labels
\setseries{labels}{md}              %  Use normal series for labels
\setshape {labels}{up}              %  Use upright shape for labels
\setfamily{membranelabels}{sf}      %  Use sans serif for membrane labels
\setseries{membranelabels}{md}      %  Use normal series for membrane labels
\setshape {membranelabels}{up}      %  Use upright shape for membrane labels
\setfamily{looplabels}{sf}          %  Use sans serif for loop labels
\setseries{looplabels}{bf}          %  Use bold face for loop labels
\setshape {looplabels}{up}          %  Use upright shape for loop labels
\looplabelcolor{Red}                %  Set loop label color to `Red'
\setfamily{TMlabels}{sf}            %  Use sans serif for TM labels
\setseries{TMlabels}{bf}            %  Use bold face for TM labels
\setshape {TMlabels}{up}            %  Use upright shape for TM labels
\TMlabelcolor{Blue}                 %  Set TM label color to `Blue'
\labelTMs{\Romancount}              %  Label the TMs with roman numbers
\setfamily{legend}{sf}              %  Use sans serif font for legend texts
\setseries{legend}{md}              %  Use normal series for legend texts
\setshape {legend}{up}              %  Use upright shape for legend texts
\setsize  {legend}{normalsize}      %  Use normal font size for legends
\legendcolor{Black}                 %  Set legend text color to `Black'
\showlegend                         %  Show the legend
\hidegrid                           %  Do not show the grid

\labelstyle{CONFLICT}               %    Label style definitions for
 {diamond}{Black}{Blue}{White}      %
 {Conflicting reports in literatur} %       SwissProt data files

\labelstyle{VARIANT}                %                |
 {diamond}{Black}{Orange}{Black}    %                |
 {Sequence variants}                %                V

\labelstyle{VARSPLIC}               %
 {diamond}{Black}{Apricot}{Black}   %
 {Splice variants}                  %

\labelstyle{MUTAGEN}                %
 {diamond}{Black}{Red}{White}       %
 {Mutation sites}                   %

\labelstyle{SIGNAL}                 %
 {square}{Black}{Yellow}{Black}     %
 {Signal peptide}                   %

\labelstyle{TRANSIT}                %
 {square}{Black}{Green}{Black}      %
 {Transit peptide}                  %

\labelstyle{PROPEP}                 %
 {square}{Black}{Red}{White}        %
 {Propeptide}                       %

\labelstyle{CHAIN}                  %
 {circ}{Black}{Aquamarine}{Blue}    %
 {Polypeptide chain}                %

\labelstyle{PEPTIDE}                %
 {circ}{Black}{Peach}{Black}        %
 {Released peptide}                 %

\labelstyle{DOMAIN}                 %
 {circ}{Black}{Turquoise}{Black}    %
 {Domain}                           %

\labelstyle{CABIND}                 %
 {circ}{Black}{Gray50}{White}       %
 {Calcium binding domain}           %

\labelstyle{DNABIND}                %
 {circ}{Black}{YellowGreen}{Black}  %
 {DNA binding domain}               %

\labelstyle{NPBIND}                 %
 {circ}{Black}{Melon}{Black}        %
 {Nucleotide phosphate binding}     %

\labelstyle{ZNFING}                 %
 {circ}{Black}{Lavender}{Black}     %
 {Zinc finger}                      %

\labelstyle{SIMILAR}                %
 {circ}{Black}{SpringGreen}{Black}  %
 {Similar region}                   %

\labelstyle{REPEAT}                 %
 {circ}{Black}{Plum}{White}         %
 {Sequence repeat}                  %

\labelstyle{SITE}                   %
 {circ}{Black}{ForestGreen}{White}  %
 {Special site}                     %
